Documentation
¶
Overview ¶
Package xstrings provides convenience string functions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CutWhitespace ¶ added in v0.6.0
CutWhitespace slices s around the first (white) space, returning the text before and after it. The found result reports whether a white space appears in s. If the white space does not appear in s, the function returns (s, "", false).
White space is determined using utf8.IsSpace and any character with Unicode's White Space property.
func JoinSpaced ¶
JoinSpaced the passed strings, ensuring they are properly separated by only a single space between each adjacent non-empty string, skipping empty strings.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.